@@ -1,4 +1,3 @@
-# type: ignore[attr-defined]
 """Awesome `data_manifestor` is a Python cli/package created with https://github.com/TezRomacH/python-package-template"""
 
 import sys
@@ -13,3 +12,7 @@ def get_version() -> str:
 
 
 version: str = get_version()
+
+__all__ = [
+    "version",
+]
