@@ -121,19 +121,23 @@ data_manifestor_project_asset_name = "data_manifestor_template"
 
 def get_project_data_manifestor_template(
     project_name: str = "default",
+    client: Optional[Any] = None,  # for integration testing, remove later
 ) -> Any:
     return get_project_asset(
         project_name,
         data_manifestor_project_asset_name,
+        client=client,
     )
 
 
 def update_project_data_manifestor_template(
     project_name: str,
     template: Template,
+    client: Optional[Any] = None,  # for integration testing, remove later
 ) -> None:
     put_project_asset(
         project_name,
         data_manifestor_project_asset_name,
         dump_Template(template),
+        client=client,
     )
