@@ -36,3 +36,7 @@ def alt_dict_to_template(data: dict[str, Any]) -> Template:
 
 def is_alt_format(data: dict[str, Any]) -> bool:
     return data.get("files") is not None
+
+
+def dump_Template(template: Template) -> Any:
+    return template_schema.dump(template)
