@@ -1,3 +1,5 @@
+from typing import Any, Dict
+
 from marshmallow import (
     Schema,
     ValidationError,
@@ -10,19 +12,14 @@ from marshmallow import (
 from .. import dataclasses
 
 
-class Dataclass(Schema):
-
-    __model__ = None
-
-    @post_load
-    def make_dataclass(self, data: dict, **kwargs):
-        return self.__model__(**data)
-
-
-class Template(Dataclass):
+class Template(Schema):
 
     __model__ = dataclasses.Template
 
     name = fields.String()
     path_prefix = fields.String(dump_default="{}-{}-{}")
     path_patterns = fields.List(fields.String())
+
+    @post_load
+    def make_dataclass(self, data: dict[str, Any], **kwargs: Any) -> Any:
+        return self.__model__(**data)
